*===================================================================;
*  Title:  PROGRAM 1 ASSIGNS AHRQ PATIENT SAFETY INDICATORS
*          TO INPATIENT RECORDS
*
*  Description:
*         ASSIGNS THE OUTCOME OF INTEREST AND POPULATION AT RISK
*         INDICATORS TO INPATIENT RECORDS.  ALSO ASSIGNS 
*         COMORBIDITY CATEGORIES.
*
*          >>>  VERSION 3.1, March 2007 <<<
*
*  USER NOTE:  Make sure you have created the format library
*              using PSFMTS.SAS BEFORE running this program.
*
*===================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PSI.SAS"; *<==USER MUST modify;

%INCLUDE CONTROL;

 TITLE2 'PROGRAM 1';
 TITLE3 'AHRQ PATIENT SAFETY INDICATORS: ASSIGN PSIS TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- PATIENT SAFETY INDICATOR (PSI) NAMING CONVENTION:      --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PATIENT SAFETY         --- ;
 * --- INDICATOR AS ONE OF THE FOLLOWING:
                (O) OBSERVED RATES
                (E) EXPECTED RATES
                (R) RISK-ADJUSTED RATES
                (S) SMOOTHED RATES
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
 * --- THE SECOND LETTER IDENTIFIES THE PSI AS A PROVIDER (P) --- ;
 * --- OR AN AREA (A) LEVEL INDICATOR.  THE                   --- ;
 * --- NEXT TWO CHARACTERS ARE ALWAYS 'PS'. THE LAST TWO      --- ;
 * --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ;
 * -------------------------------------------------------------- ;

 %MACRO ADDPRDAY; 
    %IF &PRDAY EQ 1 %THEN PRDAY1-PRDAY&NPR. ;
 %MEND;

 %MACRO ADDPOA; 
    %IF &POAFG EQ 1 %THEN DXATADMIT1-DXATADMIT&NDX.;
 %MEND;

 DATA   OUT1.&OUTFILE1. 
    (KEEP=KEY HOSPID DRG MDC AGE AGEDAY DISP LOS ATYPE ASOURCE MAREA YEAR DQTR
          AGECAT POPCAT SEXCAT RACECAT PAYCAT
          CHF VALVE PULMCIRC PERIVASC HTN_C
          PARA NEURO CHRNLUNG DM DMCX
          HYPOTHY RENLFAIL LIVER ULCER AIDS
          LYMPH METS TUMOR ARTH OBESE
          WGHTLOSS BLDLOSS ANEMDEF ALCOHOL DRUG
          PSYCH DEPRESS 
          TPPS01-TPPS20 TAPS21-TAPS27 DISCWT);
 SET   IN1.&INFILE1. 
      (KEEP=KEY DRG MDC SEX AGE AGEDAY RACE PSTCO PAY1 HOSPID DISP LOS ASOURCE ATYPE
            DX1-DX&NDX. PR1-PR&NPR. %ADDPRDAY YEAR DQTR %ADDPOA DISCWT);
           
 * -------------------------------------------------------------- ;
 * --- AREA, DIAGNOSIS AND PROCEDURE MACROS --------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='MODIFIED FIPS';
        MAREA = INPUT(PUT(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 1999 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 2003 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 %MACRO MDX(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO MDX1(FMT);

 ((PUT(DX1,&FMT.) = '1') %EXCPOA)

 %MEND;

 %MACRO MDX2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO EXCPOA;
    %IF &POAFG. EQ 1 %THEN %DO;
       OR
       (%DO I = 2 %TO &NDX.-1;
        (PUT(DX&I.,&FMT.) = '1' AND DXATADMIT&I. = 1) OR
        %END;
        (PUT(DX&NDX.,&FMT.) = '1' AND DXATADMIT&NDX. = 1))
    %END;
 %MEND;

 %MACRO MDR(FMT);

 (PUT(PUT(DRG,Z3.),&FMT.) = '1')

 %MEND;

 %MACRO MPR(FMT);

 (%DO I = 1 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;

 %MACRO MPR1(FMT);

 (PUT(PR1,&FMT.) = '1')

 %MEND;

 %MACRO MPR2(FMT);

 (%DO I = 2 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;

 %MACRO MPRCNT(FMT);

    MPRCNT = 0; 
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,&FMT.) = '1'    AND
          PUT(PR&I.,$ORPROC.) = '1' THEN MPRCNT + 1;
    %END;

 %MEND;

 %MACRO MPRDAY(FMT);

    MPRDAY = .;
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,&FMT.) = '1' AND PRDAY&I. NE . THEN DO;
          IF MPRDAY = . THEN MPRDAY = PRDAY&I;
          ELSE IF MPRDAY > PRDAY&I. THEN MPRDAY = PRDAY&I;
       END;
    %END;

 %MEND;

%MACRO ORCNT;

    ORCNT = 0;
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,$ORPROC.) = '1' THEN ORCNT + 1;
    %END;

%MEND;

%MACRO ORDAY(FMT);

    ORDAY = .;
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,$ORPROC.) = '1' AND
          PUT(PR&I.,&FMT.)    = '0' THEN DO;
          IF PRDAY&I. NE . THEN DO;
             IF ORDAY = . THEN ORDAY = PRDAY&I;
             ELSE IF ORDAY > PRDAY&I. THEN ORDAY = PRDAY&I;
          END;
       END;
    %END;

%MEND;

 * -------------------------------------------------------------- ;
 * --- DELETE RECORDS WITH MISSING VALUES FOR AGE OR SEX--------- ;
 * -------------------------------------------------------------- ;
 IF SEX LE 0 THEN DELETE;
 IF AGE LT 0 THEN DELETE;

 * -------------------------------------------------------------- ;
 * --- SET MISSING DISCHARGE WEIGHT TO ONE              --------- ;
 * -------------------------------------------------------------- ;
 IF DISCWT LT 0 THEN DISCWT = 1;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 ATTRIB FIPSTCO LENGTH=$5
   LABEL='FIPS STATE COUNTY CODE';
 FIPSTCO = PUT(PSTCO,Z5.);

 ATTRIB FIPST LENGTH=$2
   LABEL='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);

 * -------------------------------------------------------------- ;
 * --- CONDITIONALLY DEFINE METRO AREAS (MA) FROM COUNTY CODES -- ;
 * -------------------------------------------------------------- ;
 %CTY2MA

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB PAYCAT LENGTH=3
   LABEL='PATIENT PRIMARY PAYER';

 SELECT (PAY1);
   WHEN (1)  PAYCAT = 1;
   WHEN (2)  PAYCAT = 2;
   WHEN (3)  PAYCAT = 3;
   WHEN (4)  PAYCAT = 4;
   WHEN (5)  PAYCAT = 5;
   OTHERWISE PAYCAT = 6;
 END; * SELECT PAY1 ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB RACECAT LENGTH=3
   LABEL='PATIENT RACE/ETHNICITY';

 SELECT (RACE);
   WHEN (1)  RACECAT = 1;
   WHEN (2)  RACECAT = 2;
   WHEN (3)  RACECAT = 3;
   WHEN (4)  RACECAT = 4;
   WHEN (5)  RACECAT = 5;
   OTHERWISE RACECAT = 6;
 END; * SELECT RACE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB AGECAT LENGTH=3
   LABEL='PATIENT AGE';

 SELECT;
   WHEN (      AGE < 18)  AGECAT = 0;
   WHEN (18 <= AGE < 40)  AGECAT = 1;
   WHEN (40 <= AGE < 65)  AGECAT = 2;
   WHEN (65 <= AGE < 75)  AGECAT = 3;
   WHEN (75 <= AGE     )  AGECAT = 4;
 END; * SELECT AGE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB SEXCAT LENGTH=3
   LABEL='PATIENT GENDER';

 SELECT (SEX);
   WHEN (1)  SEXCAT = 1;
   WHEN (2)  SEXCAT = 2;
 END; * SELECT SEX ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB POPCAT LENGTH=3
   LABEL='PATIENT AGE';

 POPCAT=PUT(AGE,AGEFMT.);

 * -------------------------------------------------------------- ;
 * --- COUNT OR PROCEDURES AND IDENTIFY FIRST OR PROCEDURE ------ ;
 * -------------------------------------------------------------- ;
 ATTRIB ORCNT LENGTH=8
   LABEL='OR PROCEDURE COUNT';

 ATTRIB ORDAY LENGTH=8
   LABEL='OR PROCEDURE DAY';

%ORCNT;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL INDICATORS ------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO LBL;

 ATTRIB
 TPPS01 LENGTH=3
   LABEL='COMPLICATIONS OF ANESTHESIA (Numerator)'
 TPPS02 LENGTH=3
   LABEL='DEATH IN LOW MORTALITY DRGS (Numerator)'
 TPPS03 LENGTH=3
   LABEL='DECUBITUS ULCER (Numerator)'
 TPPS04 LENGTH=3
   LABEL='FAILURE TO RESCUE (Numerator)'
 TPPS05 LENGTH=3
   LABEL='FOREIGN BODY LEFT IN DURING PROC (Num)'
 TPPS06 LENGTH=3
   LABEL='IATROGENIC PNEUMOTHORAX (Numerator)'
 TPPS07 LENGTH=3
   LABEL='INFECTION DUE TO MEDICAL CARE (Num)'
 TPPS08 LENGTH=3
   LABEL='POSTOPERATIVE HIP FRACTURE (Numerator)'
 TPPS09 LENGTH=3
   LABEL='POSTOP HEMORRHAGE OR HEMATOMA (Num)'
 TPPS10 LENGTH=3
   LABEL='POSTOP PHYSIO METABOL DERANGEMENT (Num)'
 TPPS11 LENGTH=3
   LABEL='POSTOP RESPIRATORY FAILURE (Numerator)'
 TPPS12 LENGTH=3
   LABEL='POSTOPERATIVE PE OR DVT (Numerator)'
 TPPS13 LENGTH=3
   LABEL='POSTOPERATIVE SEPSIS (Numerator)'
 TPPS14 LENGTH=3
   LABEL='POSTOPERATIVE WOUND DEHISCENCE (Num)'
 TPPS15 LENGTH=3
   LABEL='ACCIDENTAL PUNCTURE/LACERATION(Num)'
 TPPS16 LENGTH=3
   LABEL='TRANSFUSION REACTION (Numerator)'
 TPPS17 LENGTH=3
   LABEL='BIRTH TRAUMA -INJURY TO NEONATE(Num)'
 TPPS18 LENGTH=3
   LABEL='OB TRAUMA - VAGINAL W INSTRUMENT (Num)'
 TPPS19 LENGTH=3
   LABEL='OB TRAUMA - VAGINAL W/O INSTRUMENT (Num)'
 TPPS20 LENGTH=3
   LABEL='OB TRAUMA - C-SECTION (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL INDICATORS ----------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TAPS21 LENGTH=3
   LABEL='FOREIGN BODY LEFT IN DURING PROC (Area Num)'
 TAPS22 LENGTH=3
   LABEL='IATROGENIC PNEUMOTHORAX (Area Numerator)'
 TAPS23 LENGTH=3
   LABEL='INFECTION DUE TO MEDICAL CARE (Area Num)'
 TAPS24 LENGTH=3
   LABEL='POSTOPERATIVE WOUND DEHISCENCE (Area Num)'
 TAPS25 LENGTH=3
   LABEL='ACCIDENTAL PUNCTURE/LACERATION(Area Num)'
 TAPS26 LENGTH=3
   LABEL='TRANSFUSION REACTION (Area Numerator)'
 TAPS27 LENGTH=3
   LABEL='POSTOP HEMORRHAGE OR HEMATOMA (Area Num)'
;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;
 LABEL
   TPPS03 = 'DECUBITUS ULCER-NO PRDAY (Numerator)'
   TPPS08 = 'POSTOP HIP FRACTURE-NO PRDAY (Num)'
   TPPS09 = 'POSTOP HEMOR OR HEMAT-NO PRDAY (Num)'
   TPPS10 = 'POSTOP PHYSIO METABO DE-NO PRDAY (Num)'
   TPPS11 = 'POSTOP RESP FAILURE-NO PRDAY (Numerator)'
   TPPS12 = 'POSTOP PE OR DVT-NO PRDAY    (Numerator)'
   TPPS14 = 'POSTOP WOUND DEHISCENCE-NO PRDAY (Num)'
   TAPS27 = 'POSTOP HEMO OR HEMA -NO PRDAY (Area Num)'
 ;
 %END;

 %MEND;

 %LBL;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AHRQ COMORBIDITY     --------------------------- ;
 * -------------------------------------------------------------- ;
%INCLUDE CMBANALY;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

   NEONATE = 0;
   IF 0 <= AGEDAY <= 28 THEN NEONATE = 1;
   ELSE IF AGEDAY = . AND AGE = 0 THEN DO;
      IF ATYPE IN (4) OR %MDX($V29D.) OR %MDX($LIVEBND.)
      THEN NEONATE = 1;
   END;

   NEWBORN = 0;
   IF NEONATE THEN DO;
      IF %MDX($LIVEBND.) AND NOT AGEDAY > 0 THEN NEWBORN = 1;
      ELSE IF ATYPE IN (4) AND AGEDAY = 0 AND NOT %MDX($LIVEB2D.)
      THEN NEWBORN = 1;
   END;
 
   NORMAL = 0;
   IF NEWBORN AND DRG IN (391) THEN NORMAL = 1;

 * -------------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL INDICATORS ---------------------- ;
 * -------------------------------------------------------------- ;

   * --- COMPLICATIONS OF ANESTHESIA                          --- ;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TPPS01 = 0;

      IF %MDX2($ANES1ID.) OR %MDX2($ANES2ID.) THEN TPPS01 = 1;

      *** Exclude principal diagnosis; 
    
      IF %MDX1($ANES1ID.) OR %MDX1($ANES2ID.) THEN TPPS01 = .;

      *** Exclude Active Drug Dependence, Active nondependent abuse
          of drugs, and self-inflicted injury;

      IF %MDX2($ANES1ID.) AND 
         (%MDX($ADRUGID.) OR %MDX($ANONDID.) OR %MDX($SELFIID.))
      THEN TPPS01 = .;

   END;

   * --- DEATH IN LOW MORTALITY DRGS                          --- ;

   IF %MDR($LOWMODR.) AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TPPS02 = 0;

      IF DISP IN (20) THEN TPPS02 = 1;
 
      *** Exclude Trauma, Immunocompomised state, and cancer;

      IF %MDX($TRAUMID.) OR %MDX($IMMUNID.) OR 
         %MPR($IMMUNIP.) OR %MDX($CANCEID.) 
      THEN TPPS02 = .;

   END;

   * --- DECUBITUS ULCER                                      --- ;

 %MACRO PS3;

 IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF MPRDAY <= ORDAY THEN TPPS03 = .;

 END;
 ELSE DO;

      IF %MPR1($DEBRIDP.) THEN TPPS03 = .;

 END;

 %MEND;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND AGE >= 18 THEN DO;

      TPPS03 = 0;
     
      IF %MDX2($DECUBID.) THEN TPPS03 = 1;
 
      *** Exclude principal diagnosis; 

      IF %MDX1($DECUBID.) THEN TPPS03 = .;

      IF %MDR($SURGIDR.) AND ORCNT > 0 THEN DO;
 
         *** Exclude if debridement or pedicle graft is the only OR procedure;
         %MPRCNT($DEBRIDP.);
         IF ORCNT = MPRCNT THEN TPPS03 = .;

         *** Exclude if debridement or pedicle graft occurs before or 
             on the same day as the first OR procedure;
         %ORDAY($DEBRIDP.);
         %MPRDAY($DEBRIDP.);
         %PS3;

      END;

      *** Exclude Hemiplegia, Paraplagia, Quadriplagia;

      IF %MDX($HEMIPID.) THEN TPPS03 = .;

      *** Exclude Spina Bifida and Anoxic Brain Damage;

      IF %MDX($SPINABD.) THEN TPPS03 = .;

      *** Exclude MDC 9 and 14;

      IF MDC IN (9, 14) THEN TPPS03 = .;

      *** Exclude LOS < 5, Admitted from Acute Care Facility or LTC;

      IF LOS < 5 OR ASOURCE IN (2,3) THEN TPPS03 = .;

   END;

   * --- FAILURE TO RESCUE                                    --- ;

   IF (%MDX2($FTR1DX.) AND
       NOT (%MDX1($FTR1DX.) OR %MDX1($FTR1EX.) OR %MDX1($AMIID.) OR %MDX1($CARDRID.) OR 
            %MDX1($CARDIID.) OR %MDX1($HEMORID.) OR %MDX1($GASTRID.) OR %MDX1($SHOCKID.) OR 
            %MDX1($TRAUMID.) OR %MDR($TRAUMDR.))) 
      OR
      (%MDX2($FTR2DX.) AND 
       NOT (%MDX1($FTR2DX.) OR %MDX1($OBEMBOL.)))
      OR
      (%MDX2($FTR3DX.) AND 
       NOT (%MDX1($FTR3DX.) OR %MDX1($FTR3EXA.) OR %MDX($FTR3EXB.) OR %MDX($IMMUNID.) OR 
            %MPR($IMMUNIP.) OR MDC IN (4)))
      OR
      (%MDX2($FTR4DX.) AND 
       NOT (%MDX1($FTR4DX.) OR %MDX($IMMUNID.) OR %MPR($IMMUNIP.) OR
            %MDX1($INFECID.) OR %MDR($INFECDR.) OR LOS < 4))
      OR
      ((%MDX2($FTR5DX.) OR %MPR($FTR5PR.)) AND 
       NOT (%MDX1($FTR5DX.) OR %MDX1($FTR5EX.) OR %MDX1($HEMORID.) OR %MDX1($TRAUMID.) OR 
            %MDR($TRAUMDR.) OR %MDX1($GASTRID.) OR MDC IN (4,5)))
      OR
      (%MDX2($FTR6DX.) AND 
       NOT (%MDX1($FTR6DX.) OR %MDX1($FTR6EX.) OR %MDX1($TRAUMID.) OR %MDR($TRAUMDR.) OR
            %MDX1($ALCHLSM.) OR MDC IN (6,7)))
   THEN DO;

      TPPS04 = 0;

      IF DISP IN (20) THEN TPPS04 = 1;

      *** Exclude Age GE 75 or Transfers from an acute care or LTC facility
          or Transferred to an acute care facility or MDC 15;

      IF AGE < 18 OR AGE >= 75 OR ASOURCE IN (2,3) OR DISP IN (2) OR MDC IN (15) THEN TPPS04 = .;

   END;

   * --- FOREIGN BODY LEFT IN DURING PROCEDURE                --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TPPS05 = 0;

      IF %MDX2($FOREIID.) THEN TPPS05 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($FOREIID.) THEN TPPS05 = .;

   END;

   * --- IATROGENIC PNEUMOTHORAX                              --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND AGE >= 18 THEN DO;

      TPPS06 = 0;

      IF %MDX2($IATROID.) THEN TPPS06 = 1;
   
      *** Exclude principal diagnosis; 

      IF %MDX1($IATROID.) THEN TPPS06 = .;

      *** Exclude Chest Trauma, Pleural effusion or MDC 14;

      IF %MDX($CTRAUMD.) OR %MDX($PLEURAD.) OR MDC IN (14)
      THEN TPPS06 = .;

      *** Exclude Thoracic surgery, Lung or pleural biopsy,
          Cardiac surgery or Diaphragmatic surgery repair;

      IF %MPR($THORAIP.) OR %MPR($LUNGBIP.) OR %MDR($CARDSDR.) OR 
         %MPR($DIAPHRP.)
      THEN TPPS06 = .;

   END;

   * --- INFECTION DUE TO MEDICAL CARE                        --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TPPS07 = 0;

      IF %MDX2($IDTMCID.) THEN TPPS07 = 1;
 
      *** Exclude principal diagnosis; 

      IF %MDX1($IDTMCID.) THEN TPPS07 = .;

      *** Exclude Immunocompromised state and Cancer;

      IF %MDX($IMMUNID.) OR %MPR($IMMUNIP.) OR
         %MDX($CANCEID.) OR %MDR($CANCEDR.) 
      THEN TPPS07 = .;
 
      *** Exclude LOS < 2; 
      IF LOS < 2 THEN TPPS07 = .;

   END;

   * --- POSTOPERATIVE HIP FRACTURE                           --- ;

 %MACRO PS8;

 IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF MPRDAY <= ORDAY THEN TPPS08 = .;

 END;
 ELSE DO;

      IF %MPR1($HIPFXIP.) THEN TPPS08 = .;

 END;

 %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND AGE >= 18 THEN DO;

      TPPS08 = 0;
  
      IF %MDX2($HIPFXID.) THEN TPPS08 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($HIPFXID.) THEN TPPS08 = .;

      *** Exclude if hip fracture repair or a related procedure is 
          the only OR procedure;
      %MPRCNT($HIPFXIP.);
      IF ORCNT = MPRCNT THEN TPPS08 = .;

      *** Exclude if hip fracture repair or a related procedure 
          occurs before or on the same day as the first OR procedure;
      %ORDAY($HIPFXIP.);
      %MPRDAY($HIPFXIP.);
      %PS8;

      *** Excludes Seizure, Syncope, Stroke, Coma, Cardiac arrest,
          Poisoning, Trauma, Delirium and other psychoses, Anoxic
          brain injury;

      IF %MDX1($SEIZUID.) OR %MDX1($SYNCOID.) OR %MDX1($STROKID.) OR
         %MDX1($COMAID.)  OR %MDX1($CARDIID.) OR %MDX1($POISOID.) OR
         %MDX1($TRAUMID.) OR %MDR($TRAUMDR.)  OR %MDX1($DELIRID.) OR
         %MDX1($ANOXIID.)
      THEN TPPS08 = .;

      *** Excludes Metastatic cancer, Lymphoid malignancy, 
          Bone malignancy, Self-inflicted injury;
 
      IF %MDX($METACID.) OR %MDX($LYMPHID.) OR %MDX($BONEMID.) OR
         %MDX($SELFIID.)
      THEN TPPS08 = .;

      *** Exclude MDC 8 and 14;

      IF MDC IN (8, 14) THEN TPPS08 = .;

   END;

   * --- POSTOPERATIVE HEMORRHAGE OR HEMATOMA                 --- ;

 %MACRO PS9;

 IF (&PRDAY. = 1 AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF (%MDX2($POHMAID.) OR %MDX2($POHMRID.)) AND MPRDAY < ORDAY
      THEN TPPS09 = .;

 END;
 ELSE DO;

      IF (%MDX2($POHMAID.) OR %MDX2($POHMRID.)) AND %MPR1($HEMIP.)
      THEN TPPS09 = .;

 END;

 %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND AGE >= 18 THEN DO;

      TPPS09 = 0;

      IF (%MDX2($POHMAID.) OR %MDX2($POHMRID.)) AND 
         (%MPR($HEMATIP.)  OR %MPR($HEMORIP.)) 
      THEN TPPS09 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($POHMAID.) OR %MDX1($POHMRID.) THEN TPPS09 = .;

      *** Exclude if control of post-operative hemorrhage or
          hematoma are the only OR procedures;
      %MPRCNT($HEMIP.);
      IF ORCNT = MPRCNT THEN TPPS09 = .;

      *** Exclude if control of post-operative hemorrhage or
          hematoma occurs before the first OR procedure;
      %ORDAY($HEMIP.);
      %MPRDAY($HEMIP.);
      %PS9;

      *** Exclude MDC 14;

      IF MDC IN (14) THEN TPPS09 = .;

   END;

   * --- POSTOPERATIVE PHYSIOLOGIC AND METABOLIC DERANGEMENTS --- ;

 %MACRO PS10;

 IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF %MDX2($PHYSIDB.) AND MPRDAY <= ORDAY THEN TPPS10 = .;

 END;
 ELSE DO;

      IF %MDX2($PHYSIDB.) AND %MPR1($DIALYIP.) THEN TPPS10 = .;

 END;

 %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND ATYPE IN (3) AND AGE >= 18 THEN DO;

      TPPS10 = 0;

      IF %MDX2($PHYSIDA.) OR (%MDX2($PHYSIDB.) AND %MPR($DIALYIP.))
      THEN TPPS10 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($PHYSIDA.) OR %MDX1($PHYSIDB.) THEN TPPS10 = .;

      *** Exclude if dialysis procedure occurs before or on the same
          day as the first OR procedure;
      %ORDAY($DIALYIP.);
      %MPRDAY($DIALYIP.);
      %PS10;

      *** Exclude Ketoacidosis, Hyperosmolarity or other Coma and
          Diabetes;

      IF %MDX2($PHYSIDA.) AND %MDX1($DIABEID.) THEN TPPS10 = .;

      *** Exclude Acute renal failure and AMI, Cardiac arrhythmia,
          Cardiac arrest, Shock, Hemorrhage, Gastrointestinal
          hemorrhage or Chronic renal failure;

      IF %MDX2($PHYSIDB.) AND (%MDX1($AMIID.) OR %MDX1($CARDRID.) OR
         %MDR($CARDRDR.) OR %MDX1($CARDIID.) OR %MDX1($SHOCKID.) OR
         %MDX1($HEMORID.) OR %MDX1($GASTRID.) OR %MDX1($CRENLFD.))
      THEN TPPS10 = .;

      *** Exclude MDC 14;

      IF MDC IN (14) THEN TPPS10 = .;

   END;

   * --- POSTOPERATIVE RESPIRATORY FAILURE                    --- ;

 %MACRO PS11N(FMT,DAYS);

    %MPRDAY(&FMT.);

    IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

       IF MPRDAY >= ORDAY + &DAYS. THEN TPPS11 = 1;

    END;
    ELSE DO;

       IF %MPR2(&FMT.) THEN TPPS11 = 1;

    END;

 %MEND;

 %MACRO PS11;

 IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF MPRDAY < ORDAY THEN TPPS11 = .;

 END;
 ELSE DO;

      IF %MPR1($TRACHIP.) THEN TPPS11 = .;

 END;

 %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND ATYPE IN (3) AND AGE >= 18 THEN DO;

      TPPS11 = 0;

      IF %MDX2($ACURFID.) THEN TPPS11 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($ACURFID.) THEN TPPS11 = .;

      *** Include in numerator if reintubation procedure occurs on the same day or
          # days after the first OR procedure;
 
      %ORDAY($BLANK.);
      %PS11N($PR9604P.,1);
      %PS11N($PR9670P.,2);
      %PS11N($PR9671P.,2);
      %PS11N($PR9672P.,0);

      *** Exclude if tracheostomy procedure is the only OR procedure;
      %MPRCNT($TRACHIP.);
      IF ORCNT = MPRCNT THEN TPPS11 = .;

      *** Exclude if tracheostomy procedure occurs before the 
          first OR procedure;
      %ORDAY($TRACHIP.);
      %MPRDAY($TRACHIP.);
      %PS11;

      *** Exclude Neuromuscular disorders;
 
      IF %MDX($NEUROMD.) THEN TPPS11 = .;

      *** Exclude MDC 4, 5, 14;
 
      IF MDC IN (4,5,14) THEN TPPS11 = .;

   END;

   * --- POSTOPERATIVE PE OR DVT                              --- ;

 %MACRO PS12;

 IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF MPRDAY <= ORDAY THEN TPPS12 = .;

 END;
 ELSE DO;

      IF %MPR1($VENACIP.) THEN TPPS12 = .;

 END;

 %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND AGE >= 18 THEN DO;

      TPPS12 = 0;

      IF %MDX2($DEEPVID.) OR %MDX2($PULMOID.) THEN TPPS12 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($DEEPVID.) OR %MDX1($PULMOID.) THEN TPPS12 = .;

      *** Exclude if Interruption of vena cava the only OR procedure;
      %MPRCNT($VENACIP.);
      IF ORCNT = MPRCNT THEN TPPS12 = .;

      *** Exclude if interruption of vena cava occurs before or on the
          same day as the first OR procedure;;

      %ORDAY($VENACIP.);
      %MPRDAY($VENACIP.);
      %PS12;

     *** Exclude MDC 14;

      IF MDC IN (14) THEN TPPS12 = .;

   END;

   * --- POSTOPERATIVE SEPSIS                                 --- ;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND ATYPE IN (3) AND AGE >= 18 THEN DO;

      TPPS13 = 0;

      IF %MDX2($SEPTIID.) THEN TPPS13 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($SEPTIID.) THEN TPPS13 = .;

      *** Exclude Infection, Immunocompromised or Cancer;

      IF %MDX1($INFECID.) OR %MDR($INFECDR.) OR 
         %MDX($IMMUNID.)  OR %MPR($IMMUNIP.) OR 
         %MDX($CANCEID.)  OR %MDR($CANCEDR.)
      THEN TPPS13 = .;

      *** Exclude Length of stay less then 4 days;

      IF LOS < 4 THEN TPPS13 = .;

      *** Exclude MDC 14;

      IF MDC IN (14) THEN TPPS13 = .;

   END;

   * --- POSTOPERATIVE WOUND DEHISCENCE                       --- ;

 %MACRO PS14;

 IF (&PRDAY. = 1 AND MPRDAYA NE . AND MPRDAYB NE .) THEN DO;

      IF MPRDAYB <= MPRDAYA THEN TPPS14 = .;

 END;
 ELSE DO;

      IF %MPR1($RECLOIP.) THEN TPPS14 = .;

 END;

 %MEND;

   IF (((YEAR < 2004 OR (YEAR = 2004 AND DQTR IN (1,2,3))) AND (%MPR($ABDOMIP.)                   )) OR
       ((YEAR > 2004 OR (YEAR = 2004 AND DQTR IN (4)    )) AND (%MPR($ABDOMIP.) OR %MPR($ABDOM2P.)))) 
      AND AGE >= 18 
   THEN DO;

      TPPS14 = 0;

      IF %MPR($RECLOIP.) THEN TPPS14 = 1;

      *** Exclude if wound reclosure occurs before or on the same
          day as the first abdominopelvic procedure;;

      %MPRDAY($ABDOMIP.); MPRDAYA = MPRDAY;
      %MPRDAY($RECLOIP.); MPRDAYB = MPRDAY;
      %PS14;

      *** Exclude Immunocompromised state;

      IF %MDX($IMMUNID.) OR %MPR($IMMUNIP.) 
      THEN TPPS14 = .;
 
      *** Exclude LOS < 2; 
      IF LOS < 2 THEN TPPS14 = .;

     *** Exclude MDC 14;

      IF MDC IN (14) THEN TPPS14 = .;

   END;

   * --- ACCIDENTAL PUNCTURE OR LACERATION                    --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND AGE >= 18 THEN DO;

      TPPS15 = 0;

      IF %MDX2($TECHNID.) THEN TPPS15 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($TECHNID.) THEN TPPS15 = .;

      *** Exclude MDC 14;

      IF MDC IN (14) THEN TPPS15 = .;

   END;

   * --- TRANSFUSION REACTION                                 --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TPPS16 = 0;
 
      IF %MDX2($TRANFID.) THEN TPPS16 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($TRANFID.) THEN TPPS16 = .;

   END;

   * --- BIRTH TRAUMA                                         --- ;

   IF NEWBORN THEN DO;

      TPPS17 = 0;

      *** Exclude Subdural or cerebral hemorrhage if preterm;

      IF %MDX($BIRTIDA.) AND NOT %MDX($PRETEID.) THEN TPPS17 = 1;

      *** Exclude Injury to skeleton if osteogenesis imperfecta;

      IF %MDX($BIRTIDB.) AND NOT %MDX($OSTEOID.) THEN TPPS17 = 1;

      IF %MDX($BIRTIDC.) THEN TPPS17 = 1;

   END;

   * --- OB TRAUMA - VAGINAL WITH INSTRUMENTATION             --- ;

   IF %MDR($VAGINDR.) AND %MPR($INSTRIP.) THEN DO;

      TPPS18 = 0;

      IF %MDX($OBTRAID.) OR %MPR($OBTRAIP.) THEN TPPS18 = 1;

   END;

   * --- OB TRAUMA - VAGINAL WITHOUT INSTRUMENTATION          --- ;

   IF %MDR($VAGINDR.) AND NOT %MPR($INSTRIP.) THEN DO;

      TPPS19 = 0;

      IF %MDX($OBTRAID.) OR %MPR($OBTRAIP.) THEN TPPS19 = 1;

   END;

   * --- OB TRAUMA - C-SECTION                                --- ;

   IF %MDR($CESARDR.) THEN DO;

      TPPS20 = 0;

      IF %MDX($OBTRAID.) OR %MPR($OBTRAIP.) THEN TPPS20 = 1;

   END;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AREA LEVEL INDICATORS -------------------------- ;
 * -------------------------------------------------------------- ;

   * --- FOREIGN BODY LEFT IN DURING PROCEDURE                --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TAPS21 = 0;

      IF %MDX($FOREIID.) THEN TAPS21 = 1;

   END;

   * --- IATROGENIC PNEUMOTHORAX                              --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND AGE >= 18 THEN DO;

      TAPS22 = 0;

      IF %MDX($IATROID.) THEN TAPS22 = 1;
   
      *** Exclude Chest Trauma, Pleural effusion or MDC 14;

      IF %MDX($CTRAUMD.) OR %MDX($PLEURAD.) OR MDC IN (14)
      THEN TAPS22 = .;

      *** Exclude Thoracic surgery, Lung or pleural biopsy,
          Cardiac surgery or Diaphragmatic surgery repair;

      IF %MPR($THORAIP.) OR %MPR($LUNGBIP.) OR %MDR($CARDSDR.) OR 
         %MPR($DIAPHRP.)
      THEN TAPS22 = .;

   END;

   * --- INFECTION DUE TO MEDICAL CARE                        --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND 
      (AGE >= 18 OR MDC IN (14)) THEN DO;

      TAPS23 = 0;

      IF %MDX($IDTMCID.) THEN TAPS23 = 1;
 
      *** Exclude Immunocompromised state and Cancer;
 
      IF %MDX($IMMUNID.) OR %MPR($IMMUNIP.) OR
         %MDX($CANCEID.) OR %MDR($CANCEDR.) 
      THEN TAPS23 = .;

   END;

   * --- POSTOPERATIVE WOUND DEHISCENCE                       --- ;

   IF AGE >= 18 THEN DO;
 
      TAPS24 = 0;

      IF %MPR($RECLOIP.) THEN TAPS24 = 1;

      *** Exclude Immunocompromised state;

      IF %MDX($IMMUNID.) OR %MPR($IMMUNIP.) 
      THEN TAPS24 = .;
 
      *** Exclude MDC 14;

      IF MDC EQ 14 THEN TAPS24 = .;

   END;

   * --- ACCIDENTAL PUNCTURE OR LACERATION                    --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND AGE >= 18 THEN DO;

      TAPS25 = 0;

      IF %MDX($TECHNID.) THEN TAPS25 = 1;

      *** Exclude MDC 14;

      IF MDC IN (14) THEN TAPS25 = .;

   END;

   * --- TRANSFUSION REACTION                                 --- ;

   IF (%MDR($MEDICDR.) OR %MDR($SURGIDR.)) AND (AGE >= 18 OR MDC IN (14)) THEN DO;

      TAPS26 = 0;
 
      IF %MDX($TRANFID.) THEN TAPS26 = 1;

   END;

   * --- POSTOPERATIVE HEMORRHAGE OR HEMATOMA                 --- ;

   IF AGE >= 18 THEN DO;

      TAPS27 = 0;

      IF (%MDX($POHMAID.) OR %MDX($POHMRID.)) AND 
         (%MPR($HEMATIP.) OR %MPR($HEMORIP.)) 
      THEN TAPS27 = 1;

      *** Exclude MDC 14;

      IF MDC IN (14) THEN TAPS27 = .;

   END;

RUN;

* --------------------------------- ;

PROC MEANS DATA=OUT1.&OUTFILE1. N NMISS MIN MAX MEAN SUM;
RUN;

PROC CONTENTS DATA=OUT1.&OUTFILE1. POSITION;
RUN;

PROC PRINT DATA=OUT1.&OUTFILE1. (OBS=24);
TITLE4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE1.";
RUN;
